Documentation
¶
Overview ¶
Package prometheus implements a metric collector backend.MetricCollector client interface for the prometheus metric collector.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PrometheusMetricCollector ¶
type PrometheusMetricCollector struct {
// contains filtered or unexported fields
}
PrometheusMetricCollector implements the runtime backend instance that implements the backend/metric.MetricCollector interface.
func NewPrometheusMetricCollector ¶
func NewPrometheusMetricCollector(ctx context.Context, addr string) (*PrometheusMetricCollector, error)
Returns a new instance of PrometheusMetricCollector. Configures opentelemetry to export metrics to a Prometheus server hosted at address `addr`.
func (*PrometheusMetricCollector) GetMetricProvider ¶
func (p *PrometheusMetricCollector) GetMetricProvider(ctx context.Context) (metric.MeterProvider, error)
Click to show internal directories.
Click to hide internal directories.